.. include:: globals.txt
.. _index:

================================
Django Project Settings
================================

Overview
======================

|app| provides custom backend and Model that allow Users to be mapped with different groups depending of the Office


.. toctree::
    :maxdepth: 1

    install
